#include <caml/misc.h>

void caml_bytes_of_uint8_array () {
  caml_fatal_error("Unimplemented Javascript primitive caml_bytes_of_uint8_array!");
}

void caml_custom_identifier () {
  caml_fatal_error("Unimplemented Javascript primitive caml_custom_identifier!");
}

void caml_js_error_of_exception () {
  caml_fatal_error("Unimplemented Javascript primitive caml_js_error_of_exception!");
}

void caml_js_get_console () {
  caml_fatal_error("Unimplemented Javascript primitive caml_js_get_console!");
}

void caml_js_html_entities () {
  caml_fatal_error("Unimplemented Javascript primitive caml_js_html_entities!");
}

void caml_js_html_escape () {
  caml_fatal_error("Unimplemented Javascript primitive caml_js_html_escape!");
}

void caml_uint8_array_of_bytes () {
  caml_fatal_error("Unimplemented Javascript primitive caml_uint8_array_of_bytes!");
}

void caml_xmlhttprequest_create () {
  caml_fatal_error("Unimplemented Javascript primitive caml_xmlhttprequest_create!");
}
